==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/GroupIcons/VpcSubnetPrivate.md <==
# VpcSubnetPrivate


```text
aws-20210730/Resource/GroupIcons/VpcSubnetPrivate
```

```text
include('aws-20210730/Resource/GroupIcons/VpcSubnetPrivate')
```



| Illustration | VpcSubnetPrivate | VpcSubnetPrivateCard | VpcSubnetPrivateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/GroupIcons/VpcSubnetPrivate.png) | ![illustration for VpcSubnetPrivate](../../../aws-20210730/Resource/GroupIcons/VpcSubnetPrivate.Local.png) | ![illustration for VpcSubnetPrivateCard](../../../aws-20210730/Resource/GroupIcons/VpcSubnetPrivateCard.Local.png) | ![illustration for VpcSubnetPrivateGroup](../../../aws-20210730/Resource/GroupIcons/VpcSubnetPrivateGroup.Local.png) |




## VpcSubnetPrivate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element VpcSubnetPrivate
include('aws-20210730/Resource/GroupIcons/VpcSubnetPrivate')

' renders the element
VpcSubnetPrivate('VpcSubnetPrivate', 'Vpc Subnet Private', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element VpcSubnetPrivate
include('aws-20210730/Resource/GroupIcons/VpcSubnetPrivate')

' renders the element
VpcSubnetPrivate('VpcSubnetPrivate', 'Vpc Subnet Private', 'an optional tech label')
@enduml
```

## VpcSubnetPrivateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element VpcSubnetPrivateCard
include('aws-20210730/Resource/GroupIcons/VpcSubnetPrivate')

' renders the element
VpcSubnetPrivateCard('VpcSubnetPrivateCard', 'Vpc Subnet Private Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element VpcSubnetPrivateCard
include('aws-20210730/Resource/GroupIcons/VpcSubnetPrivate')

' renders the element
VpcSubnetPrivateCard('VpcSubnetPrivateCard', 'Vpc Subnet Private Card', 'an optional description')
@enduml
```

## VpcSubnetPrivateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element VpcSubnetPrivateGroup
include('aws-20210730/Resource/GroupIcons/VpcSubnetPrivate')

' renders the element
VpcSubnetPrivateGroup('VpcSubnetPrivateGroup', 'Vpc Subnet Private Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element VpcSubnetPrivateGroup
include('aws-20210730/Resource/GroupIcons/VpcSubnetPrivate')

' renders the element
VpcSubnetPrivateGroup('VpcSubnetPrivateGroup', 'Vpc Subnet Private Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/GroupIcons/VpcSubnetPrivate.md <==
# VpcSubnetPrivate


```text
aws-20210730/Resource/GroupIcons/VpcSubnetPrivate
```

```text
include('aws-20210730/Resource/GroupIcons/VpcSubnetPrivate')
```



| Illustration | VpcSubnetPrivate | VpcSubnetPrivateCard | VpcSubnetPrivateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/GroupIcons/VpcSubnetPrivate.png) | ![illustration for VpcSubnetPrivate](../../../aws-20210730/Resource/GroupIcons/VpcSubnetPrivate.Local.png) | ![illustration for VpcSubnetPrivateCard](../../../aws-20210730/Resource/GroupIcons/VpcSubnetPrivateCard.Local.png) | ![illustration for VpcSubnetPrivateGroup](../../../aws-20210730/Resource/GroupIcons/VpcSubnetPrivateGroup.Local.png) |




## VpcSubnetPrivate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element VpcSubnetPrivate
include('aws-20210730/Resource/GroupIcons/VpcSubnetPrivate')

' renders the element
VpcSubnetPrivate('VpcSubnetPrivate', 'Vpc Subnet Private', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element VpcSubnetPrivate
include('aws-20210730/Resource/GroupIcons/VpcSubnetPrivate')

' renders the element
VpcSubnetPrivate('VpcSubnetPrivate', 'Vpc Subnet Private', 'an optional tech label')
@enduml
```

## VpcSubnetPrivateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element VpcSubnetPrivateCard
include('aws-20210730/Resource/GroupIcons/VpcSubnetPrivate')

' renders the element
VpcSubnetPrivateCard('VpcSubnetPrivateCard', 'Vpc Subnet Private Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element VpcSubnetPrivateCard
include('aws-20210730/Resource/GroupIcons/VpcSubnetPrivate')

' renders the element
VpcSubnetPrivateCard('VpcSubnetPrivateCard', 'Vpc Subnet Private Card', 'an optional description')
@enduml
```

## VpcSubnetPrivateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element VpcSubnetPrivateGroup
include('aws-20210730/Resource/GroupIcons/VpcSubnetPrivate')

' renders the element
VpcSubnetPrivateGroup('VpcSubnetPrivateGroup', 'Vpc Subnet Private Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element VpcSubnetPrivateGroup
include('aws-20210730/Resource/GroupIcons/VpcSubnetPrivate')

' renders the element
VpcSubnetPrivateGroup('VpcSubnetPrivateGroup', 'Vpc Subnet Private Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
